idraaak.image-fit

Integer contain and centered-cover geometry for Clojure and ClojureScript. This namespace never reads, modifies, or uploads image files.

Integer contain and centered-cover geometry for Clojure and ClojureScript.
This namespace never reads, modifies, or uploads image files.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries